-- Name: jmzdy.lua
-- 名称: 简码自定义显示
-- Version: 20240126
-- Authors: 戴石麟

---@param env Env
local function init(env)
	env.mem = Memory(env.engine, env.engine.schema, "jmzdy")
end

---@param translation Translation
---@param env Env
local function lookup(translation, env)
	local hint = { '2', '3', '7', '8', '9', '1', '4', '5', '6', '0' }
	---@type Memory
	local mem = env.mem
	local enabled = env.engine.context:get_option("is_enhanced")
		and not env.engine.context:get_option("is_hidden")
	if not enabled then
		for cand in translation:iter() do
			yield(cand)
		end
		return
	end
	-- 在增强非隐藏时的提示
	for cand in translation:iter() do
		local preedit = cand.preedit
		local is_s = string.match(preedit, "[qwrtsdfgzxcvbyphjklnm]") == preedit
		local is_sb = string.match(preedit, "[qwrtsdfgzxcvbyphjklnm][aeiou]") == preedit
		local is_ss = string.match(preedit, "[qwrtsdfgzxcvbyphjklnm][qwrtsdfgzxcvbyphjklnm]") == preedit
		if not (is_s or is_sb or is_ss) then
			yield(cand)
			goto continue
		end
		-- 首选字词
		yield(cand)
		-- 一般的情况，分为 aeiou, 23789, 14560 三组处理
		if is_s or is_sb or is_ss then
			for j = 6, #hint do
				local c = hint[j]
				mem:dict_lookup(cand.preedit .. c, false, 100)
				for dictentry in mem:iter_dict() do
					hint[j] = dictentry.text..c
				end
			end
			for j = 1, 5 do
				local c = hint[j]
				mem:dict_lookup(cand.preedit .. c, false, 100)
				for dictentry in mem:iter_dict() do
					--仅在14567上有字词时才拼接
					if hint[j+5]:len() > 1 then
						c =  c..' '..hint[j+5]
					end
					local forward = Candidate("hint", cand.start, cand._end, dictentry.text, c)
					yield(forward)
					break
				end
			end
		end
		i = i + 1
		::continue::
	end
end

local jmzdy = { init = init, func = lookup }

return jmzdy
